

local moduleName = "RangeCheck"



----------------------------
--      Localization      --
----------------------------

local L = AceLibrary("AceLocale-2.2"):new("BunchOfBars"..moduleName)

L:RegisterTranslations("enUS", function() return {
	[moduleName] = "Range Check",

	["Check frequency"] = true,
	["Frequency in seconds."] = true
} end)



----------------------------------
--      Local Declaration      --
----------------------------------

local BS = AceLibrary("Babble-Spell-2.2")

local InRange



----------------------------------
--      Module Declaration      --
----------------------------------

local plugin = BunchOfBars:NewModule(moduleName, "AceEvent-2.0")

plugin.options = {
	name = L[moduleName],
	args = {
		frequency = {
			type = "range",
			name = L["Check frequency"],
			desc = L["Frequency in seconds."],
			min  = 0.1,
            max  = 5.0,
            step = 0.1,
            get  = "GetSetFrequency",
            set  = "GetSetFrequency",
		}
	}
}

plugin.defaultDB = {
	frequency = 1.0
}



----------------------------------
--      Module Functions        --
----------------------------------

function plugin:OnInitialize()
	local class = select(2, UnitClass("player"))

	-- 40 yard range check
	if class == "PRIEST" then
		InRange = function(unit) return IsSpellInRange(BS["Flash Heal"], unit) == 1 end -- 40 yards
	elseif class == "DRUID" then
		InRange = function(unit) return IsSpellInRange(BS["Healing Touch"], unit) == 1 end -- 40 yards
	elseif class == "PALADIN" then
		InRange = function(unit) return IsSpellInRange(BS["Holy Light"], unit) == 1 end -- 40 yards
	elseif class == "SHAMAN" then
		InRange = function(unit) return IsSpellInRange(BS["Healing Wave"], unit) == 1 end -- 40 yards
	elseif class == "HUNTER" then
		InRange = function(unit) return IsSpellInRange(BS["Misdirection"], unit) == 1 end -- 100 yards
	else
		InRange = function(unit) return CheckInteractDistance(unit, 1) end -- 30 yards
	end
end


function plugin:OnEnable()
	self:ScheduleRepeatingEvent("BunchOfBars_RangeUpdate", self.UpdateAll, self.db.profile.frequency, self)
end


function plugin:OnDisable()
	self:CancelScheduledEvent("BunchOfBars_RangeUpdate")

	for _,frame in pairs(self.core.frames) do
		frame:SetAlpha(1.0)
	end
end


function plugin:OnUpdate(frame)
	if InRange(frame.unit) then -- this will also hide dead and offline players
		frame:SetAlpha(1.0)
	else
		frame:SetAlpha(0.25)
	end
end


function plugin:GetSetFrequency(value)
	if type(value) == "nil" then return self.db.profile.frequency end

	-- this check is to assure we don't reschedule the event to often
	if self.db.profile.frequency ~= value then
		self.db.profile.frequency = value
		
		self:OnEnable()
	end
end
